@@ -44,32 +44,39 @@ MAX_IN_GAME_SPD = {
 }
 
 MIN_SABER_FIELDING = {
+    'oaa': -16,
     'drs': -20,
     'tzr': -18,
     'dWAR': -2.5
 }
 MAX_SABER_FIELDING = {
+    'oaa': 16,
     'drs': 20,
     'tzr': 18,
     'dWAR': 2.5
 }
 # FOR 1B, USE A STATIC CUTOFFS INSTEAD OF RANGE
 FIRST_BASE_PLUS_2_CUTOFF = {
+    'oaa': 13,
     'drs': 17,
     'tzr': 15,
     'dWAR': 0.8
 }
 FIRST_BASE_PLUS_1_CUTOFF = {
+    'oaa': 2,
     'drs': 4,
     'tzr': 4,
     'dWAR': -0.25
 }
 # -1 1B DEFENSE ONLY APPLIES TO 2022 SET AND BEYOND
 FIRST_BASE_MINUS_1_CUTOFF = {
+    'oaa': -5,
     'drs': -5,
     'tzr': -5,
     'dWAR': -1.0
 }
+# REDUCES OUTLIERS IN OOA BY REDUCING VALUES OVER THE DEFENSE MAXIMUM
+OAA_OVER_MAX_MULTIPLIER = 0.5
 # MINIMUM REQUIRED GAMES PLAYED AT A POSITION TO QUALIFY
 NUMBER_OF_GAMES_DEFENSE = 7 
 PCT_OF_GAMES_DEFENSE = 0.15
@@ -808,24 +815,24 @@ POINT_CATEGORY_WEIGHTS = {
     f'2022-{CLASSIC_ALIAS}': {
         'position_player': {
             'defense': 65,
-            'speed': 65,
-            'onbase': 200,
-            'average': 55,
-            'slugging': 170,
+            'speed': 75,
+            'onbase': 220,
+            'average': 70,
+            'slugging': 180,
             'home_runs': 50
         },
         'starting_pitcher': {
-            'ip': 115,
-            'onbase': 470,
+            'ip': 110,
+            'onbase': 425,
             'average': 35,
-            'slugging': 255,
+            'slugging': 230,
             'out_distribution': 30,
         },
         'relief_pitcher': {
             'ip': 0, # IP IS ADJUSTED ELSEWHERE
-            'onbase': 174,
+            'onbase': 150,
             'average': 25,
-            'slugging': 112,
+            'slugging': 100,
             'out_distribution': 20,
         }
     },
@@ -923,7 +930,7 @@ POINTS_POSITIONAL_DEFENSE_MULTIPLIER = {
         'IF': 1.0,
     },
     f'2022-{CLASSIC_ALIAS}': {
-        'C': 1.0,
+        'C': 1.2,
         '1B': 0.5,
         '2B': 1.0,
         '3B': 1.0,
@@ -934,7 +941,7 @@ POINTS_POSITIONAL_DEFENSE_MULTIPLIER = {
         'IF': 1.0,
     },
     f'2022-{EXPANDED_ALIAS}': {
-        'CA': 1.0,
+        'CA': 1.2,
         '1B': 0.5,
         '2B': 1.0,
         '3B': 1.0,
